"""Naval Fate.

Usage:
  git-cloner clon [(-u <user> | --user=<user>)] [-f] [(-o <out>| --out=<out>)]
                  (-c <org> | --org=<org>) (-l <limit> | --limit=<limit>)
                  [(-s <file> | --save=<file>)] [--ssh]
  git-cloner make-repos [(-u <user> | --user=<user>)] [-f] [(-i <in>| --in=<in>)] [(-s <file> | --save=<file>)]
                  (-t <type> | --type=<type>) --priv-token=<token> (-h | --host=<host>) [--ssh]
  git-cloner (-h | --help)
  git-cloner --version

Options:
  -l --limit=<limit>    Limit of repositories
  -u --user=<user>      User to connect
  -v --version          Show version.
  -c --org=<org>        Origin to read repositories
  -h --help             Show help
  -f                    Force remove directories
  -o --out=<out>        Output directory
  -i --in=<in>          Input directory
  -s --save=<file>      Save Output resutl into a file
  --ssh                 Use ssh instead https
  -t --type=<type>      Indicate the type of repository gitlab is only supported jet
  --priv-token=<token>  Indicate the path to the private token where the token is
  -h --host=<host>      Indicate the host. i.e git@gitlab.com:4123


"""
from docopt import docopt

from git_cloner.github_wrapper import clones
from git_cloner.github_wrapper import list_repos
from git_cloner.utils.config import Config
from git_cloner.utils.utils import *


def main():
    version = read('VERSION')
    arguments = docopt(__doc__, version='Git cloner {version}'.format(version=version))
    run(arguments)


def run(arguments):
    Config.load_config(arguments)
    repos = list_repos(Config.get_config().org, Config.get_config().limit)
    clones(repos)
