import json
import unittest

import os
import shutil
import time
from mock_decorators.function_mock import FunctionMock

from git_cloner.model.repository import Repository
from git_cloner.operations import mass_cloner
from git_cloner.utils import utils
from git_cloner.utils.config import Config
import pkg_resources

test_dir = "/tmp/test_tmp"
response_filepath = pkg_resources.resource_filename("tests", "resources/request_fhuertas_org.json")


class MassClonerTest(unittest.TestCase):
    def setUp(self):
        shutil.rmtree(test_dir, ignore_errors=True)
        os.makedirs(test_dir)
        time.sleep(1)

    def tearDown(self):
        shutil.rmtree(test_dir, True)
        time.sleep(1)

    def serial_it(self):
        def test_mass_cloner_user():
            config = Config.load_config({})
            config.type = "github"
            config.target_user = "yunxao"
            config.dir_out = test_dir
            mass_cloner.mass_cloner()
            repos = [name for name in os.listdir(test_dir) if Repository(os.path.join(test_dir, name)).check_git()]
            self.assertEqual(len(repos), 10)

        def test_mass_cloner_org():
            config = Config.load_config({})
            config.type = "github"
            config.org = "fhuertasorgfortest"
            config.ssh = True
            config.dir_out = test_dir
            mass_cloner.mass_cloner()
            repos = [name for name in os.listdir(test_dir) if Repository(os.path.join(test_dir, name)).check_git()]
            self.assertEqual(len(repos), 1)

        def test_mass_cloner_fail():
            config = Config.load_config({})
            config.type = "github"
            config.org = "fhuertasorgfortest"
            config.ssh = True
            config.dir_out = test_dir

            def mock_request(*args, **kwargs):
                result = json.loads(utils.read(response_filepath))
                return result

            @FunctionMock(utils, 'make_request', mock_request, False)
            def inner_test():
                mass_cloner.mass_cloner()

            inner_test()
            repos = [name for name in os.listdir(test_dir) if Repository(os.path.join(test_dir, name)).check_git()]
            self.assertEqual(len(repos), 1)

        self.setUp()
        test_mass_cloner_user()
        self.setUp()
        test_mass_cloner_org()
        self.setUp()
        test_mass_cloner_fail()
