import unittest

import os
import shutil

from git_cloner.model.remotes.github_remote import GithubRemote
from git_cloner.model.repository import Repository, RawRepository
from git_cloner.utils.config import Config
from tests.git_cloner.utils.gen_utils import *

test_dir = "/tmp/test_tmp"


class RepositoryIT(unittest.TestCase):
    def setUp(self):
        shutil.rmtree(test_dir, ignore_errors=True)
        os.makedirs(test_dir)

    def tearDown(self):
        shutil.rmtree(test_dir, True)

    # This tests have problems if are executed in parallel
    def serials_it(self):

        def creating_with_cloning():
            remote = GithubRemote.build_from_url("https://github.com/fhuertas/scala_base.git")
            repo = Repository.clone(remote, test_dir)

            self.assertTrue(repo.check_git())
            self.assertEqual(len(repo.remotes), 1)
            self.assertEqual(repo.remotes[0].get_name(), "origin")
            self.assertEqual(repo.remotes[0].build_remote_url(), "https://github.com/fhuertas/scala_base.git")

        def creating_with_cloning_ssh():
            remote = GithubRemote("fhuertas", "mock_decorators", True)
            repo = Repository.clone(remote, test_dir)

            self.assertTrue(repo.check_git())
            self.assertEqual(len(repo.remotes), 1)
            self.assertEqual(repo.remotes[0].get_name(), "origin")
            self.assertEqual(repo.remotes[0].build_remote_url(), "git@github.com:fhuertas/mock_decorators.git")

        def clone_repo_github():
            Config.load_config({}).ssh = True
            gen_raw_repo = generate_repo_github()
            gen_raw_repo['owner']['login'] = "fhuertas"
            gen_raw_repo['name'] = "monkey"
            raw_repo = RawRepository(gen_raw_repo)
            result = raw_repo.clone(test_dir)
            self.assertTrue(result.check_git())

        creating_with_cloning()
        creating_with_cloning_ssh()
        clone_repo_github()
